@@ -20,14 +20,6 @@
 
 #define QT_FEATURE_framework -1
 
-#define QT_FEATURE_cxx11 1
-
-#define QT_FEATURE_cxx14 1
-
-#define QT_FEATURE_cxx17 1
-
-#define QT_FEATURE_cxx1z 1
-
 #define QT_FEATURE_cxx20 -1
 
 #define QT_FEATURE_cxx2a -1
@@ -36,10 +28,6 @@
 
 #define QT_FEATURE_cxx2b -1
 
-#define QT_FEATURE_c99 1
-
-#define QT_FEATURE_c11 1
-
 #define QT_FEATURE_reduce_relocations -1
 
 #define QT_FEATURE_signaling_nan 1
@@ -65,11 +53,11 @@
 #define QT_FEATURE_opensslv30 1
 
 
-#define QT_VERSION_STR "6.5.1"
+#define QT_VERSION_STR "6.6.1"
 
 #define QT_VERSION_MAJOR 6
 
-#define QT_VERSION_MINOR 5
+#define QT_VERSION_MINOR 6
 
 #define QT_VERSION_PATCH 1
 #define QT_LARGEFILE_SUPPORT 64
